@@ -3,8 +3,11 @@ from __future__ import absolute_import
 # flake8: noqa
 
 # import apis into api package
+from lusid.api.aggregation_api import AggregationApi
 from lusid.api.allocations_api import AllocationsApi
 from lusid.api.application_metadata_api import ApplicationMetadataApi
+from lusid.api.complex_market_data_api import ComplexMarketDataApi
+from lusid.api.configuration_recipe_api import ConfigurationRecipeApi
 from lusid.api.cut_label_definitions_api import CutLabelDefinitionsApi
 from lusid.api.data_types_api import DataTypesApi
 from lusid.api.derived_transaction_portfolios_api import DerivedTransactionPortfoliosApi
@@ -12,6 +15,7 @@ from lusid.api.entities_api import EntitiesApi
 from lusid.api.instruments_api import InstrumentsApi
 from lusid.api.legal_entities_api import LegalEntitiesApi
 from lusid.api.orders_api import OrdersApi
+from lusid.api.persons_api import PersonsApi
 from lusid.api.portfolio_groups_api import PortfolioGroupsApi
 from lusid.api.portfolios_api import PortfoliosApi
 from lusid.api.property_definitions_api import PropertyDefinitionsApi
